# T1 Models

## T1VFA

::: qmrpy.models.t1.T1VFA
    options:
      members:
        - __init__
        - fit
        - fit_linear
        - fit_image
        - forward

## T1InversionRecovery

::: qmrpy.models.t1.T1InversionRecovery
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T1DESPOT1HIFI

::: qmrpy.models.t1.T1DESPOT1HIFI
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T1MP2RAGE

::: qmrpy.models.t1.T1MP2RAGE
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward
